@@ -1,8 +1,8 @@
 
-# public user level API: docs, help and arg cleaning
+# public user level API: computing color (sets), measure, IO for many formats and spaces
 
 package Graphics::Toolkit::Color;
-our $VERSION = '1.95';
+our $VERSION = '1.91';
 
 use v5.12;
 use warnings;
@@ -124,41 +124,16 @@ EOH
     $self->{'values'}->formatted( @$arg{qw/in as suffix range precision/} );
 }
 
-sub name         {
-    my ($self, @args) = @_;
-    return $self->{'values'}->name unless @args;
-    my $arg = _split_named_args( \@args, 'from', [], {from => 'default', all => 0, full => 0});
-    my $help = <<EOH;
-    GTC method 'name' accepts three optional, named arguments:
-    name ( ...
-        'CSS'                 # color naming scheme works as only positional argument
-        from => 'CSS'         # same scheme (defaults to internal: X + CSS + PantoneReport)
-        from => ['SVG', 'X']  # more color naming schemes at once, without duplicates
-        all => 1              # returns list of all names associated with the object's values
-        full => 1             # adds color scheme name to the color name. 'SVG:red'
-EOH
-    return Graphics::Toolkit::Color::Name::from_values( $self->{'values'}->shaped, @$arg{qw/from all full/});
-}
-
+sub name         { $_[0]{'values'}->name }
 sub closest_name {
-    my ($self, @args) = @_;
-    my $arg = _split_named_args( \@args, 'from', [], {from => 'default', all => 0, full => 0});
-    my $help = <<EOH;
-    GTC method 'name' accepts three optional, named arguments:
-    closest_name ( ...
-        'CSS'                 # color naming scheme works as only positional argument
-        from => 'CSS'         # same scheme (defaults to internal: X + CSS + PantoneReport)
-        from => ['SVG', 'X']  # more color naming schemes at once, without duplicates
-        all => 1              # returns list of all names associated with the object's values
-        full => 1             # adds color scheme name to the color name. 'SVG:red'
-EOH
-    my ($name, $distance) = Graphics::Toolkit::Color::Name::closest_from_values(
-                                $self->{'values'}->shaped, @$arg{qw/from all full/});
+    my ($self) = shift;
+    my ($name, $distance) = $self->{'values'}->closest_name_and_distance;
     return wantarray ? ($name, $distance) : $name;
 }
 
 sub distance {
     my ($self, @args) = @_;
+    @args = %{$args[0]} if @args == 1 and ref $args[0] eq 'HASH';
     my $arg = _split_named_args( \@args, 'to', ['to'], {in => $default_space_name, select => undef, range => undef});
     my $help = <<EOH;
     GTC method 'distance' accepts as arguments either a scalar color definition or
@@ -188,8 +163,7 @@ EOH
     }
     my $range_def = $color_space->shape->try_check_range_definition( $arg->{'range'} );
     return $range_def unless ref $range_def;
-    Graphics::Toolkit::Color::Space::Hub::distance(
-        $self->{'values'}->normalized, $target_color->{'values'}->normalized, $color_space->name ,$arg->{'select'}, $range_def );
+    $self->{'values'}->distance( $target_color->{'values'}, $color_space, $arg->{'select'}, $range_def);
 }
 
 ## single color creation methods #######################################
@@ -381,20 +355,19 @@ Graphics::Toolkit::Color - calculate color (sets), IO many spaces and formats
     use Graphics::Toolkit::Color qw/color/;
 
     my $red = Graphics::Toolkit::Color->new('red');  # create color object
-    say $red->add_value( 'blue' => 255 )->name;      # red + blue = 'magenta'
+    say $red->add_value( 'blue' => 255 )->name;      # red + blue = 'fuchsia'
     my @blue = color( 0, 0, 255)->values('HSL');     # 240, 100, 50 = blue
     $red->mix( to => [HSL => 0,0,80], amount => 10); # mix red with a little grey
     $red->gradient( to => '#0000FF', steps => 10);   # 10 colors from red to blue
-    my @base_triadic = $red->complement( 3 );        # get fitting red green and blue
-    my @reds = $red->cluster( radius => 4, distance => 1 );
+    my @base_triple = $red->complement( 3 );         # get fitting red green and blue
 
 
 =head1 DEPRECATION WARNING
 
 Methods of the old API ( I<string>, I<rgb>, I<red>,
 I<green>, I<blue>, I<rgb_hex>, I<rgb_hash>, I<hsl>, I<hue>, I<saturation>,
-I<lightness>, I<hsl_hash>, I<add>, I<set>, I<blend>, I<blend_with>,
-I<gradient_to>, I<rgb_gradient_to>, I<hsl_gradient_to>, I<complementary>)
+I<lightness>, I<hsl_hash>, I<blend>, I<blend_with>, I<gradient_to>,
+I<rgb_gradient_to>, I<hsl_gradient_to>, I<complementary>)
 will be removed with release of version 2.0.
 
 =head1 DESCRIPTION
@@ -405,20 +378,19 @@ Its main purpose is the creation of related colors or sets of them,
 such as gradients, complements and others. But you can use it also to
 convert and/or reformat color definitions.
 
-GTC are read only, one color representing objects with no additional
-dependencies. Create them in many different ways (see L</CONSTRUCTOR>).
+GTC are read only, color holding objects with no additional dependencies.
+Create them in many different ways (see section L</CONSTRUCTOR>).
 Access its values via methods from section L</GETTER>.
 Measure differences with the L</distance> method. L</SINGLE-COLOR>
 methods create one new object that is related to the current one and
 L</COLOR-SETS> methods will create a group of colors, that are not
 only related to the current color but also have relations between each other.
-Error messages will appear as return values instead of the expected result.
+Error messages will appear as return values.
 
-While this module can understand and output color values to many
-L<color spaces|Graphics::Toolkit::Color::Space::Hub/COLOR-SPACES>,
-L<RGB|Graphics::Toolkit::Color::Space::Hub/RGB>
-is the (internal) primal one, because GTC is about colors that can be
-shown on the screen, and these are usually encoded in I<RGB>.
+While this module can understand and output color values in many spaces,
+such as I<LAB>, I<NCol>, I<YIQ> and many more, I<RGB> is the (internal),
+primal one, because GTC is about colors that can be shown on the screen,
+and these are usually encoded in I<RGB>.
 Humans access colors on hardware level (eye) in I<RGB>, on cognition level
 in I<HSL> (brain) and on cultural level (language) with names.
 Having easy access to all of those plus some color math and many formats
@@ -437,20 +409,6 @@ From now on any input that the constructor method C<new> accepts,
 is called a B<color definition>.
 
 
-=head2 new({ r => $r, g => $g, b => $b })
-
-Most clear, flexible and longest input format: a hash with long or short
-axis names as keys with fitting values. This can be C<red>, C<green> and
-C<blue> or C<r>, C<g> and C<b> or names from any other color space.
-Upper or lower case doesnt matter.
-
-    my $red = Graphics::Toolkit::Color->new( r => 255, g => 0, b => 0 );
-    my $red = Graphics::Toolkit::Color->new({r => 255, g => 0, b => 0}); # works too
-                        ... ->new( Red => 255, Green => 0, Blue => 0);   # also fine
-              ... ->new( Hue => 0, Saturation => 100, Lightness => 50 ); # same color
-                  ... ->new( Hue => 0, whiteness => 0, blackness => 0 ); # still the same
-
-
 =head2 new( [$r, $g, $b] )
 
 takes a triplet of integer I<RGB> values (red, green and blue : 0 .. 255).
@@ -466,6 +424,20 @@ Out of range values will be corrected (clamped).
     my $red = Graphics::Toolkit::Color->new([ RGB => 255, 0, 0]); # and brackets
 
 
+=head2 new({ r => $r, g => $g, b => $b })
+
+Hash with the keys C<red>, C<green> and Cblue> does the same as shown in
+previous paragraph, only more declarative. Casing of the key strings will
+be normalised and all axis names can be substituted with short ones, which
+are in most cases the first letters of the long name.
+
+    my $red = Graphics::Toolkit::Color->new( r => 255, g => 0, b => 0 );
+    my $red = Graphics::Toolkit::Color->new({r => 255, g => 0, b => 0}); # works too
+                        ... ->new( Red => 255, Green => 0, Blue => 0);   # also fine
+              ... ->new( Hue => 0, Saturation => 100, Lightness => 50 ); # same color
+                  ... ->new( Hue => 0, whiteness => 0, blackness => 0 ); # still the same
+
+
 =head2 new('rgb($r,$g,$b)')
 
 String format that is supported by CSS (I<css_string> format): it starts
@@ -498,10 +470,10 @@ also acceptable (I<RGB> only).
 
 =head2 new('name')
 
-Get a color object by providing a name from the X11, HTML (CSS) or SVG
-scheme or a Pantone report. UPPER or CamelCase will be normalized to
-lower case and inserted underscore letters ('_') will be ignored as perl
-does in numbers (1_000 == 1000). All available names are listed
+Get a color by providing a name from the X11, HTML (CSS) or SVG standard
+or a Pantone report. UPPER or CamelCase will be normalized to lower case
+and inserted underscore letters ('_') will be ignored as perl does in
+numbers (1_000 == 1000). All available names are listed
 L<here | Graphics::Toolkit::Color::Name::Constant/NAMES>.
 
     my $color = Graphics::Toolkit::Color->new('Emerald');
@@ -512,7 +484,7 @@ L<here | Graphics::Toolkit::Color::Name::Constant/NAMES>.
 
 Get a color by name from a specific scheme or standard as provided by an
 external module L<Graphics::ColorNames>::* , which has to be installed
-separately. * is a placeholder for the scheme name, which might be:
+separately. * is a placeholder for the pallet name, which might be:
 Crayola, CSS, EmergyC, GrayScale, HTML, IE, Mozilla, Netscape, Pantone,
 PantoneReport, SVG, VACCC, Werner, Windows, WWW or X. In latter case
 I<Graphics::ColorNames::X> has to be installed. You can get them all at
@@ -601,55 +573,21 @@ they appear by default you can surpress them by adding C<suffix =E<gt> ''>
 
 =head2 name
 
-Returns the normalized name string (lower case, without I<'_'>) that
-represents the I<RGB> values of this color in the default color scheme,
-which is I<X11> + I<HTML> (I<SVG>) + I<Pantone report>
-(see L<all names|Graphics::Toolkit::Color::Name::Constant/NAMES>).
-These are the same who can be used with L</new('name')>.
-
-Alternatively you may provide named arguments or one positional argument,
-which requires the same input as the named argument C<from>. It names one
-or a list of color schemes, from which the name will be selected then.
-Your otions are C<CSS>, C<Crayola>, C<EmergyC>, C<GrayScale>, C<HTML>,
-C<IE>, C<Mozilla>, C<Netscape>, C<Pantone>, C<PantoneReport>, C<SVG>,
-C<VACCC>, C<Werner>, C<Windows>, C<WWW> and C<X> plus self created naming
-schemes (see L<Graphics::Toolkit::Color::Name::Scheme>). Please note
-that all listed schemes are parts of modules that have to be installed
-separately. For your convenience I created the module
-L<Bundle::Graphics::ColorNames> to install them all at once. If you
-try to use a scheme from a not installed module your will get an error
-message instead of a color name.
-
-The second named argument is C<all>, which needs to be a perly boolean.
-It defaults to false. But when set to 1 you will get a list of all names
-that are associated with the current values. There will be no duplicates,
-when several schemes are searched.
-
-A third named argument is C<full>, also needing a perly boolean, that
-defaults to false. When set C<true> (1), the schema is part of the returned
-color name. These full names are also accepted by the constructor.
-
-    $blue->name();                                   # 'blue'
-    $blue->name('SVG');                              # 'blue'
-    $blue->name( from => [qw/CSS X/], all => 1);     # 'blue', 'blue1'
-    $blue->name( from => 'CSS', full => 1);          # 'CSS:blue'
+Returns the normalized name (lower case, without I<'_'>) of the color,
+held by the object - even when the object was created with numerical values.
+It returns an empty string when no color constant with the exact same values
+was found in the I<X11> or I<HTML> (I<SVG>) standard or the I<Pantone report>.
+If several constants have matching values, the shortest name will be returned.
+All names are listed: L<here|Graphics::Toolkit::Color::Name::Constant/NAMES>.
+(See also: L</new('name')>)
 
 
 =head2 closest_name
 
-Works almost identical as method L</name>, but guarantees a none empty
-result, unless invoking a weird empty color scheme - the method returns
-scalar context a color name, which has the shortest L</distance> in I<RGB>
-to the current color. In list context, you get additionally the just
-mentioned distance as a second return value.
-
-All arguments work as mentioned above. The only difference (due to the
-second return value), multiple names (when requested) have to come in the
-form of an ARRAY (as the first return value).
-
-    my $name = $red_like->closest_name;              # closest name in default scheme
-    my $name = $red_like->closest_name('HTML');      # closest HTML constant
-    ($red_name, $distance) = $red_like->closest_name;
+Returns in scalar context a color L</name>, which has the shortest
+L</distance> in RGB to the current color.
+In list context, you get additionally the just mentioned distance
+as a second return value.
 
 
 =head2 distance
@@ -661,8 +599,7 @@ either the only argument or the named argument L</to>, which is the only
 required one.
 
 The C<distance> is measured in I<RGB> color space unless told otherwise
-by the argument L</in>. Please use the I<CIELAB> or I<CIELUV> space, if
-you are interested in getting a result that matches the human perception.
+by the argument L</in>.
 
 The third argument is named C<select>. It's useful if you want to regard
 only certain dimensions (axis). For instance if you want to know only
@@ -747,12 +684,12 @@ employ the C<amount> argument, which is the weight the mixed in color(s)
 get, counted in percentages. The remaining percentage to 100 is the weight
 of the color, held by the caller object. This would be naturally nothing,
 if the C<amount> is greater than hundret, which is especially something
-to consider, if mixing more than two colors. Then both C<to> and C<amount>
-have to get an array of colors and respectively their amounts (same order).
+to consider, if mixing more than two colors. Then you provide the argument
+C<to> and C<amount> with an array of colors and respectively their amounts.
 Obviously both arrays MUST have the same length. If the sum of amounts is
 greater than 100 the original color is ignored but the weight ratios will
 be kept. You may actually give C<amount> a scalar value while mixing a list
-of colors. Then the amount is applied to every color mentioned under the
+of colors. Then the amount is applied to every color mentioned unter the
 C<to> argument. In this case you go over the sum of 100% very quickly.
 
     $blue->mix( 'silver');                                         # 50% silver, 50% blue
@@ -840,7 +777,6 @@ The bigger the absolute numeric value the bigger the effect. Please have
 in mind that values over 2 result is a very strong tilt.
 
 Optional is the named argument L</in> (color space - details behind link).
-Tip: use C<oklab> and C<cieluv> spaces for visually smooth gradients.
 
     # we turn to grey
     my @colors = $c->gradient( to => $grey, steps => 5);
@@ -896,14 +832,14 @@ to 255 (0..255). In order to change that, many methods accept the named
 argument C<range>. When only one interger value provided, it changes the
 upper bound on all three axis and as lower bound is assumed zero.
 Let's say you need I<RGB16> values with a range of 0 .. 65536,
-then you type C<< range => 65536 >> or C<< range => 2**16 >>.
+then you type C<range =<gt> 65536> or C<range =<gt> 2**16>.
 
 If you provide an ARRAY ref you can change the upper bounds of all axis
 individually and in order to change even the lower boundaries, use ARRAY
 refs even inside that. For instance in C<HSL> the C<hue> is normally
 0 .. 359 and the other two axis are 0 .. 100. In order to set C<hue>
 to -100 .. 100 but keep the other two untouched you would have to insert:
-C<< range => [[-100,100],100,100] >>.
+C<range =&gt; [[-100,100],100,100]>.
 
 
 =head2 to
@@ -951,36 +887,6 @@ L<Color::Similarity>
 
 =back
 
-=head1 ACKNOWLEDGEMENT
-
-These people contributed by providing patches, bug reports and useful
-comments:
-
-=over 4
-
-=item *
-
-Petr Pisar  (ppisar)
-
-=item *
-
-Slaven Rezić (srezic)
-
-=item *
-
-Gábor Szabó (szabgab)
-
-=item *
-
-Gene Boggs (GENE)
-
-=item *
-
-Stefan Reddig (sreagle)
-
-=back
-
-
 =head1 AUTHOR
 
 Herbert Breunung, <lichtkind@cpan.org>
