@@ -9,7 +9,7 @@ use Graphics::Toolkit::Color::Space;
 my $cmy_def = Graphics::Toolkit::Color::Space->new( axis => [qw/cyan magenta yellow/] );
    $cmy_def->add_converter('RGB', \&invert, \&invert );
 
-sub invert { map { 1 - $_ } @{$_[0]} }
+sub invert { [ map {1 - $_} @{$_[0]} ] }
 
 $cmy_def;
 
